<?php
/**
 * Add function to widgets_init that'll load our widget.
 */
add_action( 'widgets_init', 'bk_register_widget_social_counters' );

function bk_register_widget_social_counters() {
	register_widget( 'bk_widget_social_counters' );
}

/**
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 */
class bk_widget_social_counters extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function __construct() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'doris-widget doris--social-counter', 'description' => esc_html__('Displays Social Item Counters.', 'doris') );

		/* Create the widget. */
		parent::__construct( 'bk_widget_social_counters', esc_html__('[Doris] Widget Social Counters', 'doris'), $widget_ops);
	}
    
	/**
	 *display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );
        
        $widget_opts = array();
        $title = $instance['title'];
        
        if($instance['facebook_url'] != '') :      
            $socialItems['facebook']['url']     = $instance['facebook_url'];
        endif;
        if($instance['twitter_url'] != '') :      
            $socialItems['twitter']['url']     = $instance['twitter_url'];
        endif;
        if($instance['youtube_channel'] != '') :      
            $socialItems['youtube']['url']     = $instance['youtube_channel'];
            $socialItems['youtube']['api']     = isset($instance['youtube_api']) ? $instance['youtube_api'] : '';
        endif;
        if($instance['instagram_accesstoken'] != '') :      
            $socialItems['instagram']['accesstoken']     = $instance['instagram_accesstoken'];
        endif;
        if($instance['dribbble_url'] != '') :      
            $socialItems['dribbble']['url']     = $instance['dribbble_url'];
        endif;
        if($instance['pinterest_url'] != '') :      
            $socialItems['pinterest']['url']     = $instance['pinterest_url'];
        endif;
        
        // Update Database
        doris_widget::bk_update_social_json($socialItems);
        
        echo ($before_widget);
        
        ?>
        <div class="widget__title">
    		<h4 class="widget__title-text"><?php echo esc_html($title);?></h4>
    	</div>
        <div class="doris-widget-social-counter-counter">
            <div class="doris-widget-social-counter__inner">
                <ul class="list-unstyled list-space-xs">
                    <?php 
                        foreach ($socialItems as $socialItem => $socialVal) :
                            echo doris_widget::bk_socialItem__counters_render($socialItem);
                        endforeach;
                    ?>
                </ul>
            </div>
        </div>
        <?php
        
        /* After widget (defined by themes). */
		echo ($after_widget);
	}
	
	/**
	 * update widget settings
	 */
	function update($new_instance, $old_instance) {
		$instance = $old_instance;
        $instance['title']          = $new_instance['title'];
        $instance['facebook_url']   = strip_tags($new_instance['facebook_url']);
        $instance['twitter_url']    = strip_tags($new_instance['twitter_url']);
        $instance['youtube_channel']= strip_tags($new_instance['youtube_channel']);
        $instance['youtube_api']= strip_tags($new_instance['youtube_api']);
        $instance['instagram_accesstoken']      = strip_tags($new_instance['instagram_accesstoken']);
        $instance['dribbble_url']   = strip_tags($new_instance['dribbble_url']);
        $instance['pinterest_url']  = strip_tags($new_instance['pinterest_url']);
		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {
		$defaults = array(
                        'title'             => 'Stay Connected', 
                        'facebook_url'      => '', 
                        'twitter_url'       => '',
                        'youtube_channel'       => '',
                        'youtube_api'       => '',
                        'instagram_url'     => '',
                        'dribbble_url'      => '',
                        'pinterest_url'     => '',
                        );
		$instance = wp_parse_args((array) $instance, $defaults);
	?>
        <p>
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><strong><?php esc_html_e('[Optional] Title:', 'doris'); ?></strong></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" value="<?php if( !empty($instance['title']) ) echo esc_attr($instance['title']); ?>" />
		</p>

        <p>
			<label for="<?php echo esc_attr($this->get_field_id( 'facebook_url' )); ?>"><strong><?php esc_html_e('Facebook URL:', 'doris'); ?></strong></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('facebook_url')); ?>" name="<?php echo esc_attr($this->get_field_name('facebook_url')); ?>" value="<?php if( !empty($instance['facebook_url']) ) echo esc_attr($instance['facebook_url']); ?>" />
            <i><?php esc_attr_e('eg. https://www.facebook.com/envato','doris') ?></i>
        </p>
        
        <p>
			<label for="<?php echo esc_attr($this->get_field_id( 'twitter_url' )); ?>"><strong><?php esc_html_e('Twitter URL:', 'doris'); ?></strong></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('twitter_url')); ?>" name="<?php echo esc_attr($this->get_field_name('twitter_url')); ?>" value="<?php if( !empty($instance['twitter_url']) ) echo esc_attr($instance['twitter_url']); ?>" />
            <i><?php esc_attr_e('eg. https://www.twitter.com/envato','doris') ?></i>
        </p>
        
        <p>
			<label for="<?php echo esc_attr($this->get_field_id( 'youtube_channel' )); ?>"><strong><?php esc_html_e('Youtube Channel ID:', 'doris'); ?></strong></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('youtube_channel')); ?>" name="<?php echo esc_attr($this->get_field_name('youtube_channel')); ?>" value="<?php if( !empty($instance['youtube_channel']) ) echo esc_attr($instance['youtube_channel']); ?>" />
            <i><a href="https://commentpicker.com/youtube-channel-id.php"><?php esc_attr_e('Get your Channel ID by this tool: https://commentpicker.com/youtube-channel-id.php','doris') ?></a></i>
        </p>
        <p>
			<label for="<?php echo esc_attr($this->get_field_id( 'youtube_api' )); ?>"><strong><?php esc_html_e('Youtube API Key:', 'doris'); ?></strong></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('youtube_api')); ?>" name="<?php echo esc_attr($this->get_field_name('youtube_api')); ?>" value="<?php if( !empty($instance['youtube_api']) ) echo esc_attr($instance['youtube_api']); ?>" />
            <i><a href="https://console.developers.google.com/"><?php esc_attr_e('Get the API Key here: https://console.developers.google.com/','doris') ?></a></i>
        </p>

        <p>
			<label for="<?php echo esc_attr($this->get_field_id( 'instagram_accesstoken' )); ?>"><strong><?php esc_html_e('Instagram Access Token:', 'doris'); ?></strong></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('instagram_accesstoken')); ?>" name="<?php echo esc_attr($this->get_field_name('instagram_accesstoken')); ?>" value="<?php if( !empty($instance['instagram_accesstoken']) ) echo esc_attr($instance['instagram_accesstoken']); ?>" />
            <i><a href="http://instagram.pixelunion.net"><?php esc_attr_e('Generate the access token here','doris')?></a> </i>
        </p>
        
        <p>
			<label for="<?php echo esc_attr($this->get_field_id( 'dribbble_url' )); ?>"><strong><?php esc_html_e('Dribbble URL:', 'doris'); ?></strong></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('dribbble_url')); ?>" name="<?php echo esc_attr($this->get_field_name('dribbble_url')); ?>" value="<?php if( !empty($instance['dribbble_url']) ) echo esc_attr($instance['dribbble_url']); ?>" />
            <i><?php esc_attr_e('eg. https://dribbble.com/envato','doris') ?></i>
        </p>
        
        <p>
			<label for="<?php echo esc_attr($this->get_field_id( 'pinterest_url' )); ?>"><strong><?php esc_html_e('Pinterest URL:', 'doris'); ?></strong></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('pinterest_url')); ?>" name="<?php echo esc_attr($this->get_field_name('pinterest_url')); ?>" value="<?php if( !empty($instance['pinterest_url']) ) echo esc_attr($instance['pinterest_url']); ?>" />
            <i><?php esc_attr_e('eg. https://pinterest.com/envato','doris') ?></i>
        </p>
        
<?php
	}
}
?>
