<?php
/**
 * Add function to widgets_init that'll load our widget.
 */
add_action( 'widgets_init', 'bk_register_widget_subscribe' );

function bk_register_widget_subscribe() {
	register_widget( 'bk_widget_subscribe' );
}

/**
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 */
class bk_widget_subscribe extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function __construct() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'atbs-widget atbs-subscribe', 'description' => esc_html__('Displays Subscribe Form.', 'doris') );

		/* Create the widget. */
		parent::__construct( 'bk_widget_subscribe', esc_html__('[Doris] Widget Subscribe', 'doris'), $widget_ops);
	}
    
	/**
	 *display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );
        
        $widget_opts = array();
        $title       = $instance['title'];
        $shortcode   = $instance['mailchim_shortcode'];
        $bg_color    = $instance['bg_color'];
        
        $bgStyle = '';
        if($bg_color != '') :
            $bgStyle = 'style="background-color: '.$bg_color.';"';
        endif;
        
        echo ($before_widget);
        
        echo '<div class="subscribe__inner text-center" '.$bgStyle.'>';
        echo '<div class="inside__title">';
        echo '<h4 class="inside__title">'. esc_html($title).'</h4>';
        echo '</div>';
        if($shortcode != ''):
        echo do_shortcode($shortcode);
        endif;
                        
        echo '</div>';
        
        
        
        /* After widget (defined by themes). */
		echo ($after_widget);
	}
	
	/**
	 * update widget settings
	 */
	function update($new_instance, $old_instance) {
		$instance = $old_instance;
        $instance['title']              = $new_instance['title'];
        $instance['mailchim_shortcode'] = $new_instance['mailchim_shortcode'];
        $instance['bg_color'] = $new_instance['bg_color'];
		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {
		$defaults = array('title' => 'Subscribe Us', 'mailchim_shortcode' => '', 'bg_color' => '');
		$instance = wp_parse_args((array) $instance, $defaults);
	?>
    <p>
		<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><strong><?php esc_html_e('[Optional] Title:', 'doris'); ?></strong></label>
		<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" value="<?php if( !empty($instance['title']) ) echo esc_attr($instance['title']); ?>" />
	</p>
    
    <p>
		<label for="<?php echo esc_attr($this->get_field_id( 'mailchim_shortcode' )); ?>"><strong><?php esc_html_e('Mailchimp Shortcode:', 'doris'); ?></strong></label>
		<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('mailchim_shortcode')); ?>" name="<?php echo esc_attr($this->get_field_name('mailchim_shortcode')); ?>" value="<?php if( !empty($instance['mailchim_shortcode']) ) echo esc_attr($instance['mailchim_shortcode']); ?>" />
    </p>
    
    <p>
		<label for="<?php echo esc_attr($this->get_field_id( 'bg_color' )); ?>"><strong><?php esc_html_e('[Optional] Background Color:', 'doris'); ?></strong></label>
		<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('bg_color')); ?>" name="<?php echo esc_attr($this->get_field_name('bg_color')); ?>" value="<?php if( !empty($instance['bg_color']) ) echo esc_attr($instance['bg_color']); ?>" />
	</p>
<?php
	}
}
?>
