<?php

/**
	ReduxFramework Config File
	For full documentation, please visit: https://github.com/ReduxFramework/ReduxFramework/wiki
**/

if ( !class_exists( "ReduxFramework" ) ) {
	return;
} 

if ( !class_exists( "Redux_Framework_config" ) ) {
	class Redux_Framework_config {

		public $args = array();
		public $sections = array();
		public $theme;
		public $ReduxFramework;

		public function __construct( ) {

			// Just for demo purposes. Not needed per say.
			$this->theme = wp_get_theme();

			// Set the default arguments
			$this->setArguments();
			
			// Set a few help tabs so you can see how it's done
			$this->setHelpTabs();

			// Create the sections and fields
			$this->setSections();
			
			if ( !isset( $this->args['opt_name'] ) ) { // No errors please
				return;
			}
			
			$this->ReduxFramework = new ReduxFramework($this->sections, $this->args);

			add_filter('redux/options/'.$this->args['opt_name'].'/sections', array( $this, 'dynamic_section' ) );

		}


		/**

			This is a test function that will let you see when the compiler hook occurs. 
			It only runs if a field	set with compiler=>true is changed.

		**/

		function compiler_action($options, $css) {

		}

		/**
		 
		 	Custom function for filtering the sections array. Good for child themes to override or add to the sections.
		 	Simply include this function in the child themes functions.php file.
		 
		 	NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
		 	so you must use get_template_directory_uri() if you want to use any of the built in icons
		 
		 **/

		function dynamic_section($sections){
		    return $sections;
		}
		
		
		/**

			Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.

		**/
		
		function change_arguments($args){
		    //$args['dev_mode'] = true;
		    
		    return $args;
		}
			
		
		/**

			Filter hook for filtering the default value of any given field. Very useful in development mode.

		**/

		function change_defaults($defaults){
		    $defaults['str_replace'] = "Testing filter hook!";
		    
		    return $defaults;
		}


		public function setSections() {

			/**
			 	Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
			 **/


			// Background Patterns Reader
			$sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
			$sample_patterns_url  = ReduxFramework::$_url . '../sample/patterns/';
			$sample_patterns      = array();

			ob_start();

			$ct = wp_get_theme();
			$this->theme = $ct;
			$item_name = $this->theme->get('Name'); 
			$tags = $this->theme->Tags;
			$screenshot = $this->theme->get_screenshot();
			$class = $screenshot ? 'has-screenshot' : '';

			$customize_title = sprintf( esc_html__( 'Customize &#8220;%s&#8221;','doris' ), $this->theme->display('Name') );

			?>
			<div id="current-theme" class="<?php echo esc_attr( $class ); ?>">
				<?php if ( $screenshot ) : ?>
					<?php if ( current_user_can( 'edit_theme_options' ) ) : ?>
					<a href="<?php echo esc_url(wp_customize_url()); ?>" class="load-customize hide-if-no-customize" title="<?php echo esc_attr( $customize_title ); ?>">
						<img src="<?php echo esc_url( $screenshot ); ?>" alt="<?php esc_attr_e( 'Current theme preview', 'doris' ); ?>" />
					</a>
					<?php endif; ?>
					<img class="hide-if-customize" src="<?php echo esc_url( $screenshot ); ?>" alt="<?php esc_attr_e( 'Current theme preview', 'doris' ); ?>" />
				<?php endif; ?>

				<h4>
					<?php echo esc_attr($this->theme->display('Name')); ?>
				</h4>

				<div>
					<ul class="theme-info">
						<li><?php printf( esc_html__('By %s','doris'), $this->theme->display('Author') ); ?></li>
						<li><?php printf( esc_html__('Version %s','doris'), $this->theme->display('Version') ); ?></li>
						<li><?php echo '<strong>'.__('Tags', 'doris').':</strong> '; ?><?php printf( $this->theme->display('Tags') ); ?></li>
					</ul>
					<p class="theme-description"><?php echo esc_attr($this->theme->display('Description')); ?></p>
					<?php if ( $this->theme->parent() ) {
						printf( ' <p class="howto">' . esc_html__( 'This <a href="%1$s">child theme</a> requires its parent theme, %2$s.', 'doris' ) . '</p>',
							__( 'http://codex.wordpress.org/Child_Themes','doris' ),
							$this->theme->parent()->display( 'Name' ) );
					} ?>
					
				</div>

			</div>

			<?php
			$item_info = ob_get_contents();
			    
			ob_end_clean();

			$sampleHTML = '';

            /*
             * ---> CSS selectors outputs
             */

            $primary_color_output_bg = '';
            $primary_color_output = '';

            // Primary color background.
            $primary_color_output_bg .= '.primary-color-bg, .btn[class*="st-btn-"]:before, input[type="submit"][type="submit"]:hover, .st-btn-solid-primary, a.btn.st-btn-solid-primary';

            // Primary color.
            $primary_color_output .= 'a, a:visited, a:hover, a:focus, a:active, .primary-color, .bypostauthor .comment-author .fn, .st-btn-primary, .st-btn-primary:hover, .st-btn-primary:focus, .st-btn-primary:active, input[type="submit"][type="submit"], .st-btn-outline-primary, a.btn.st-btn-outline-primary, .block-heading, .block-heading__title, .block-heading-tabs, .block-heading-tabs > li > a';

            $primary_font = array('.post__title, .entry-title, h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6, .text-font-primary, .social-tile__title, .widget_recent_comments .recentcomments > a, .widget_recent_entries li > a, .modal-title.modal-title, .author-box .author-name a, .comment-author, .widget_calendar caption, .widget_categories li>a, .widget_meta ul, .widget_recent_comments .recentcomments>a, .widget_recent_entries li>a, .widget_pages li>a, .mobile-header-btn, 
                                    .author-box .author-name a, .widget__title .widget__title-text, .doris-about-me .about__title, .single-entry .post--single .share, .single-entry .post--single .tags-title,
                                    .widget .entry-author__name, a.entry-author__name, .block-heading__title, .comments-title, .comment-reply-title, .comment-form label');

            $secondary_font = array('.text-font-secondary, .block-heading__subtitle, .widget_nav_menu ul, .typography-copy blockquote, .comment-content blockquote,
                                    .doris-design .site-footer__section-right p, .author-meta p');
            
            $tertiary_font = array('.meta-text, a.meta-text, .meta-font, a.meta-font, .text-font-tertiary, input[type="button"]:not(.btn), input[type="reset"]:not(.btn), input[type="submit"]:not(.btn), .btn, label, .category-tile__name, .page-nav, .post-score, .post-score-hexagon .post-score-value, .post__cat, a.post__cat, .entry-cat, a.entry-cat, .read-more-link, .post__meta, .entry-meta, .entry-author__name, a.entry-author__name, .comments-count-box, .widget__title-text, .social-tile__count, .widget_recent_comments .comment-author-link, .post-sharing__title, .post-sharing--simple .sharing-btn, .entry-action-btn, .entry-tags-title, .post-categories__title, .posts-navigation__label, .comments-title__text, .comments-title .add-comment, .comment-metadata, .comment-metadata a, .comment-reply-link, .countdown__digit, .modal-title, .comment-meta, .comment .reply, .wp-caption, .gallery-caption, .widget-title, .btn, .countdown__digit, .doris-widget-indexed-posts-a .posts-list>li .post__thumb:after, 
                                    .single-standard  .entry-meta, .post--single .entry-meta__bottom-right, .post--single .entry-author__name, .post--single .entry-meta__bottom-left,
                                    .post--single a.post__cat, .post--single .entry-meta__top, .widget-post-horizontal .post__meta .time,
                                    .doris-pagination .doris-pagination__item, .big-post--horizontal-d-style-1 .post__cat, .post-list--horizontal-c .post-meta time,
                                    .button__readmore, .small-featured-posts .post-meta .entry-author,
                                    .doris-post--vertical-list .view, .doris-post--vertical-list .time,
                                    .doris-post--vertical-list a.post__cat, .meta__item time, .meta__item .title, a.doris-cat,
                                    .author-meta .author__name, .post-horizontal-a .share-post ul>li, .post-horizontal-a .share-post span,
                                    .single-entry .post--single .entry-tags');
            $menu_font = array( '.top-bar__nav .navigation > li > a,
                                    .doris-main-nav .navigation--main > li > a,
                                    .navigation--main > li > a,
                                    .navigation .sub-menu, .navigation-bar-btn, .navigation, .menu');
            /*
             * ---> END CSS selectors outputs
             */

            
			// ACTUAL DECLARATION OF SECTIONS
            
                $this->sections[] = array(
    				'icon' => 'el-icon-wrench',
    				'title' => esc_html__('General Settings', 'doris'),
    				'fields' => array(
                        array(
    						'id'=>'bk-primary-color',
    						'type' => 'color',
    						'title' => esc_html__('Primary color', 'doris'), 
    						'subtitle' => esc_html__('Pick a primary color for the theme.', 'doris'),
    						'default' => '#325534',
                            'transparent' => false,
    						'validate' => 'color',
						),
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-font',
    				'title' => esc_html__('Typography', 'doris'),
                    'desc'  => esc_html__( 'It is recommended to use maximum 3 different font families for the sake of design consistency and load speed.', 'doris' ),
    				'fields' => array(
                        array(
                            'id'          => 'body-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Body text', 'doris' ),
                            'google'      => true,
                            // Disable google fonts. Won't work if you haven't defined your google api key
                            'font-backup' => true,
                            // Select a backup non-google font in addition to a google font
                            'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
                            'font-weight'    => false,
                            'subsets'       => true, // Only appears if google is true and subsets not set to false
                            'font-size'     => false,
                            'line-height'   => false,
                            'text-align'    => false,
                            //'word-spacing'  => true,  // Defaults to false
                            'letter-spacing'=> true,  // Defaults to false
                            'color'         => false,
                            'preview'       => true, // Disable the previewer
                            'all_styles'  => true,
                            // Enable all Google Font style/weight variations to be added to the page
                            'output'      => 'body',
                            // An array of CSS selectors to apply this font style to dynamically
                            'units'       => 'px',
                            // Defaults to px
                            'subtitle'    => esc_html__( 'Typography option for body text.', 'doris' ),
                            'default'     => array(
                                'font-family' => 'Rubik',
                                'font-backup' => 'Arial, Helvetica, sans-serif'
                            ),
                        ),
                        array(
                            'id'          => 'heading-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Heading', 'doris' ),
                            'google'      => true,
                            // Disable google fonts. Won't work if you haven't defined your google api key
                            'font-backup' => true,
                            // Select a backup non-google font in addition to a google font
                            'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
                            'font-weight'    => false,
                            'subsets'       => true, // Only appears if google is true and subsets not set to false
                            'font-size'     => false,
                            'line-height'   => false,
                            'text-align'    => false,
                            //'word-spacing'  => true,  // Defaults to false
                            'letter-spacing'=> true,  // Defaults to false
                            'color'         => false,
                            'preview'       => true, // Disable the previewer
                            'all_styles'  => true,
                            // Enable all Google Font style/weight variations to be added to the page
                            'output'      => $primary_font,
                            // An array of CSS selectors to apply this font style to dynamically
                            'units'       => 'px',
                            // Defaults to px
                            'subtitle'    => esc_html__( 'Typography option for title and heading.', 'doris' ),
                            'default'     => array(
                                'font-family' => 'Playfair Display',
                                'font-backup' => 'Arial, Helvetica, sans-serif'
                            ),
                        ),
                        array(
                            'id'          => 'meta-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Secondary', 'doris' ),
                            'google'      => true,
                            // Disable google fonts. Won't work if you haven't defined your google api key
                            'font-backup' => true,
                            // Select a backup non-google font in addition to a google font
                            'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
                            'font-weight'    => false,
                            'subsets'       => true, // Only appears if google is true and subsets not set to false
                            'font-size'     => false,
                            'line-height'   => false,
                            'text-align'    => false,
                            //'word-spacing'  => true,  // Defaults to false
                            'letter-spacing'=> true,  // Defaults to false
                            'color'         => false,
                            //'preview'       => false, // Disable the previewer
                            'all_styles'  => true,
                            // Enable all Google Font style/weight variations to be added to the page
                            'output'      => $secondary_font,
                            // An array of CSS selectors to apply this font style to dynamically
                            'units'       => 'px',
                            // Defaults to px
                            'subtitle'    => esc_html__( 'Typography option for secondary text such as subtitle, sub menu, ...', 'doris' ),
                            'default'     => array(
                                'font-family' => 'Rubik',
                                'font-backup' => 'Arial, Helvetica, sans-serif'
                            ),
                        ),
                        array(
                            'id'          => 'tertiary-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Tertiary font', 'doris' ),
                            'google'      => true,
                            // Disable google fonts. Won't work if you haven't defined your google api key
                            'font-backup' => true,
                            // Select a backup non-google font in addition to a google font
                            'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
                            'font-weight'    => false,
                            'text-align'    => false,
                            'subsets'       => true, // Only appears if google is true and subsets not set to false
                            'font-size'     => false,
                            'line-height'   => false,
                            'word-spacing'  => false,  // Defaults to false
                            'letter-spacing'=> true,  // Defaults to false
                            'color'         => false,
                            //'preview'       => false, // Disable the previewer
                            'all_styles'  => true,
                            // Enable all Google Font style/weight variations to be added to the page
                            'output'      => $tertiary_font,
                            // An array of CSS selectors to apply this font style to dynamically
                            'units'       => 'px',
                            // Defaults to px
                            'subtitle'    => esc_html__( 'Typography option for tertiary text such as post meta, button, ...', 'doris' ),
                            'default'     => array(
                                'font-family' => 'Rubik',
                                'font-backup' => 'Arial, Helvetica, sans-serif'
                            ),
                        ),
                        array(
                            'id'          => 'menu-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Menu Nav font', 'doris' ),
                            'google'      => true,
                            // Disable google fonts. Won't work if you haven't defined your google api key
                            'font-backup' => true,
                            // Select a backup non-google font in addition to a google font
                            'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
                            'font-weight'    => false,
                            'text-align'    => false,
                            'subsets'       => true, // Only appears if google is true and subsets not set to false
                            'font-size'     => false,
                            'line-height'   => false,
                            'word-spacing'  => false,  // Defaults to false
                            'letter-spacing'=> true,  // Defaults to false
                            'color'         => false,
                            //'preview'       => false, // Disable the previewer
                            'all_styles'  => true,
                            // Enable all Google Font style/weight variations to be added to the page
                            'output'      => $menu_font,
                            // An array of CSS selectors to apply this font style to dynamically
                            'units'       => 'px',
                            // Defaults to px
                            'subtitle'    => esc_html__( 'Typography option for tertiary text such as post meta, button, ...', 'doris' ),
                            'default'     => array(
                                'font-family' => 'Playfair Display',
                                'font-backup' => 'Arial, Helvetica, sans-serif'
                            ),
                        ),
                        array(
                            'id'=>'section-text-button-start',
                            'title' => esc_html__('Text Button', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
    						'id'      =>'bk-load-more-text',
    						'type'    => 'text',
    						'title'   => esc_html__('Load More Text', 'doris'),
                            'default' => esc_html__('Load more news', 'doris'),
						),
                        array(
    						'id'      =>'bk-no-more-text',
    						'type'    => 'text',
    						'title'   => esc_html__('No More Text', 'doris'),
                            'default' => esc_html__('No more news', 'doris'),
						),
                        array(
                            'id'=>'section-text-button-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ),
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-photo',
    				'title' => esc_html__('Header', 'doris'),
    				'fields' => array(
                        array(
                            'id' => 'section-sticky-menu-start',
                            'title' => esc_html__('Sticky Menu', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),	
                        array(
    						'id'=>'bk-sticky-menu-switch',
    						'type' => 'button_set',
    						'title' => esc_html__('Sticky Bar', 'doris'),
    						'subtitle' => esc_html__('Enable / Disable Sticky Bar Function', 'doris'),
    						'default'   => 1,
                            'options'   => array(
                                1   => esc_html__( 'Enable', 'doris' ),
				                0   => esc_html__( 'Disable', 'doris' ),
                            ),
						),
                        array(
    						'id'=>'bk-sticky-menu-logo',
                            'required' => array(
                                'bk-sticky-menu-switch','equals', 1
                            ),
    						'type' => 'media', 
    						'url'=> true,
    						'title' => esc_html__('Sticky Bar Logo', 'doris'),
    						'subtitle' => esc_html__('Upload logo of your site that is displayed in sticky bar', 'doris'),
                            'placeholder' => esc_html__('No media selected','doris')
						),
                        array(
                            'id' => 'section-sticky-menu-end',
                            'type' => 'section',                             
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id' => 'section-site-branding-start',
                            'title' => esc_html__('Site Branding', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
    						'id'=>'bk-logo',
    						'type' => 'media', 
    						'url'=> true,
    						'title' => esc_html__('Site Logo', 'doris'),
    						'subtitle' => esc_html__('Upload logo of your site that is displayed in header', 'doris'),
                            'placeholder' => esc_html__('No media selected','doris')
						),
                        array(
    						'id'=>'bk-site-logo-size-option',
    						'type' => 'select',
                            'required'  => array (
                                'bk-header-type','equals',array( 'site-header-1', 'site-header-2', 'site-header-3', 'site-header-7', 'site-header-8', 'site-header-9' )
                            ),
    						'title' => esc_html__('Site Logo Size Option ', 'doris'),
    						'subtitle' => esc_html__('Select between Original Logo Image Size or Customize the Logo Size', 'doris'),
    						'default' => 'original',
                            'options'   => array(
				                'original'      => esc_html__( 'Original Logo Image Size', 'doris' ),
                                'customize'     => esc_html__( 'Customize the Logo Size', 'doris' ),
                            ),
						),
                        array(
                            'id' => 'site-logo-width',
                            'type' => 'slider',
                            'required' => array(
                                'bk-site-logo-size-option', 'equals' , array( 'customize' )
                            ),
                            'title' => esc_html__('Site Logo Width (px)', 'doris'),
                            'default' => 300,
                            'min' => 0,
                            'step' => 10,
                            'max' => 1000,
                            'display_value' => 'text'
                        ),
                        array(
    						'id'=>'bk-mobile-logo',
    						'type' => 'media', 
    						'url'=> true,
    						'title' => esc_html__('Mobile Logo', 'doris'),
    						'subtitle' => esc_html__('Upload logo of your site that is displayed in mobile header', 'doris'),
                            'placeholder' => esc_html__('No media selected','doris')
						),
                        array(
                            'id' => 'section-site-branding-end',
                            'type' => 'section',                             
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id' => 'section-offcanvas-mobile-menu-start',
                            'title' => esc_html__('Off-canvas Menu - Mobile', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),	
                        array(
    						'id'=>'bk-offcanvas-mobile-menu',
    						'type' => 'select',
                            'data' => 'menu_location',
    						'title' => esc_html__('Select a Menu', 'doris'),
    						'default' => 'main-menu',
						),	
                        array(
    						'id'=>'bk-offcanvas-mobile-logo',
    						'type' => 'media', 
    						'url'=> true,
    						'title' => esc_html__('Off-Canvas Logo', 'doris'),
    						'subtitle' => esc_html__('Upload logo of your site that is displayed in Off-Canvas Menu', 'doris'),
                            'placeholder' => esc_html__('No media selected','doris')
						),
                        array(
    						'id'       =>'bk-offcanvas-mobile-social',
    						'type'     => 'select',
                            'multi'    => true,
    						'title' => esc_html__('Off-Canvas Social Media', 'doris'),
    						'subtitle' => esc_html__('Set up social links for site', 'doris'),
    						'options'  => array('fb'=>'Facebook', 'twitter'=>'Twitter', 'linkedin'=>'Linkedin',
                                               'pinterest'=>'Pinterest', 'instagram'=>'Instagram', 'dribbble'=>'Dribbble', 
                                               'youtube'=>'Youtube', 'vimeo'=>'Vimeo', 'vk'=>'VK', 'vine'=>'Vine',
                                               'snapchat'=>'SnapChat', 'rss'=>'RSS'),
    						'default' => array('fb'=>'', 'twitter'=>'', 'linkedin'=>'', 'pinterest'=>'', 'instagram'=>'', 'dribbble'=>'', 
                                                'youtube'=>'', 'vimeo'=>'', 'vk'=>'', 'vine'=>'', 'snapchat'=>'', 'rss'=>'')
						),
                        array(
                            'id' => 'section-offcanvas-mobile-menu-end',
                            'type' => 'section',                             
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id' => 'section-social-header-start',
                            'title' => esc_html__('Header Social Items', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),	
                        array(
    						'id'       =>'bk-social-header',
    						'type'     => 'select',
                            'multi'    => true,
    						'title' => esc_html__('Social Media', 'doris'),
    						'subtitle' => esc_html__('Select social items for the website', 'doris'),
    						'options'  => array('fb'=>'Facebook', 'twitter'=>'Twitter', 'linkedin'=>'Linkedin',
                                               'pinterest'=>'Pinterest', 'instagram'=>'Instagram', 'dribbble'=>'Dribbble', 
                                               'youtube'=>'Youtube', 'vimeo'=>'Vimeo', 'vk'=>'VK', 'vine'=>'Vine',
                                               'snapchat'=>'SnapChat', 'rss'=>'RSS'),
    						'default' => array('fb'=>'', 'twitter'=>'', 'linkedin'=>'', 'pinterest'=>'', 'instagram'=>'', 'dribbble'=>'', 
                                                'youtube'=>'', 'vimeo'=>'', 'vk'=>'', 'vine'=>'', 'snapchat'=>'', 'rss'=>'')
						),
                        array(
                            'id' => 'section-social-header-end',
                            'type' => 'section',                             
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ),
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-share',
    				'title' => esc_html__('Social Media', 'doris'),
    				'fields' => array(
                         array(
                            'id'=>'section-social-links-start',
                            'title' => esc_html__('Social Links', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
    						'id'=>'bk-social-media-links',
    						'type' => 'text',
    						'title' => esc_html__('Social media links', 'doris'),
    						'subtitle' => esc_html__('Set up social links for the website', 'doris'),
    						'options' => array('fb'=>'Facebook Url', 'twitter'=>'Twitter Url', 'linkedin'=>'Linkedin Url',
                                               'pinterest'=>'Pinterest Url', 'instagram'=>'Instagram Url', 'dribbble'=>'Dribbble Url', 
                                               'youtube'=>'Youtube Url', 'vimeo'=>'Vimeo Url', 'vk'=>'VK Url', 'vine'=>'Vine URL',
                                               'snapchat'=>'SnapChat Url', 'rss'=>'RSS Url'),
    						'default' => array('fb'=>'', 'twitter'=>'', 'linkedin'=>'', 'pinterest'=>'', 'instagram'=>'', 'dribbble'=>'', 
                                                'youtube'=>'', 'vimeo'=>'', 'vk'=>'', 'vine'=>'', 'snapchat'=>'', 'rss'=>'')
						),
                        array(
                            'id'=>'section-social-links-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ), 
                        array(
                            'id'=>'section-sharebox-start',
                            'title' => esc_html__('Social Share', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id'=>'bk-fb-sw',
                            'type' => 'switch',
                            'title' => esc_html__('Enable Facebook share link', 'doris'),
                            'default' => 1,
    						'on' => esc_html__('Enabled', 'doris'),
    						'off' => esc_html__('Disabled', 'doris'),
                        ),
                        array(
                            'id'=>'bk-tw-sw',
                            'type' => 'switch',
                            'title' => esc_html__('Enable Twitter share link', 'doris'),
                            'default' => 1,
    						'on' => esc_html__('Enabled', 'doris'),
    						'off' => esc_html__('Disabled', 'doris'),
                        ),
                        array(
                            'id'=>'bk-gp-sw',
                            'type' => 'switch',
                            'title' => esc_html__('Enable Google+ share link', 'doris'),
                            'default' => 1,
    						'on' => esc_html__('Enabled', 'doris'),
    						'off' => esc_html__('Disabled', 'doris'),
                        ),
                        array(
                            'id'=>'bk-pi-sw',
                            'type' => 'switch',
                            'title' => esc_html__('Enable Pinterest share link', 'doris'),
                            'default' => 1,
    						'on' => esc_html__('Enabled', 'doris'),
    						'off' => esc_html__('Disabled', 'doris'),
                        ),
                        array(
                            'id'=>'bk-li-sw',
                            'type' => 'switch',
                            'title' => esc_html__('Enable Linkedin share link', 'doris'),
                            'default' => 1,
    						'on' => esc_html__('Enabled', 'doris'),
    						'off' => esc_html__('Disabled', 'doris'),
                        ),
                        array(
                            'id'=>'section-sharebox-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ), 
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-indent-left',
    				'title' => esc_html__('Single Page', 'doris'),
    				'fields' => array(
                        array(
                			'id'        => 'bk-post-view--cache-time',
                            'title'     => esc_html__('Post View Cache Time (in second)', 'doris'),
                            'desc'      => esc_html__('Default: 300 means 5 minutes', 'doris'),
                            'type'      => 'slider',
                            'default'   => 300,
                            'min'       => 0,
                            'step'      => 5,
                            'max'       => 3600,
                            'display_value' => 'text'
                		),
                        array(
    						'id'=>'bk-single-template',
    						'type' => 'image_select', 
                            'class' => 'bk-single-post-layout--global-option',
    						'title' => esc_html__('Post Layout', 'doris'),
                            'options' => array(
                                'single-1' => array(
                                    'alt' => 'Single Template 1',
                                    'img' => get_template_directory_uri().'/images/admin_panel/single_page/single-1.png',
                                ),
                                'single-2' => array(
                                    'alt' => 'Single Template 2',
                                    'img' => get_template_directory_uri().'/images/admin_panel/single_page/single-2.png',
                                ),
                                'single-3' => array(
                                    'alt' => 'Single Template 3',
                                    'img' => get_template_directory_uri().'/images/admin_panel/single_page/single-3.png',
                                ),
                                'single-4' => array(
                                    'alt' => 'Single Template 4',
                                    'img' => get_template_directory_uri().'/images/admin_panel/single_page/single-4.png',
                                ),
                                'single-5' => array(
                                    'alt' => 'Single Template 5',
                                    'img' => get_template_directory_uri().'/images/admin_panel/single_page/single-5.png',
                                ),
                            ),
                            'default' => 'single-1',
						),
                        array(
                            'title' => esc_html__( 'Featured Image Config', 'doris' ),
                            'id' => 'bk-feat-img-status',
                            'type'     => 'button_set',
                			'options'  => array(              
                                1 => esc_html__( 'On', 'doris' ),
                                0 => esc_html__( 'Off', 'doris' ),
        				    ),
                			'default'   => 1,
                        ),
                        array(
                            'title' => esc_html__( 'Single Page Meta Items', 'doris' ),
                            'id' => 'bk-single-meta-items',
                            'type'     => 'select',
                			'options'  => array(              
                                8 => esc_html__( 'Author + Date', 'doris' ),
                                9 => esc_html__( 'Author + Date + Comments', 'doris' ),
                                10 => esc_html__( 'Author + Date + Views', 'doris' ),
                                11 => esc_html__( 'Author + Date + Comments + Views', 'doris' ),
                                12 => esc_html__( 'Author + Comments + Views', 'doris' ),
        				    ),
                			'default'   => 10,
                        ),
                        array(
                            'id'=>'section-single-sidebar-start',
                            'title' => esc_html__('Sidebar', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id'        => 'bk_post_sb_select',  
                            'type'      => 'select',
                            'data'      => 'sidebars', 
                            'multi'     => false,
                            'title'     => esc_html__('Single Page Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Choose sidebar for single page', 'doris'),
                            'default'   => 'home_sidebar',
                        ),
                        array(
                            'id'        => 'bk_post_sb_position',  
                            'type'      => 'image_select',
                            'multi'     => false,
                            'title'     => esc_html__('Sidebar Postion', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                                'right' => array(
                                                    'alt' => 'Sidebar Right',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/single_page/sb-right.png',
                                                ),
                                                'left' => array(
                                                    'alt' => 'Sidebar Left',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/single_page/sb-left.png',
                                                ),
                                        ),
                            'default' => 'right',
                        ),
                        array(
                            'id'        => 'bk_post_sb_sticky',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Stick Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Enable Stick Sidebar / Disable Stick Sidebar', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                1   => esc_html__( 'Enable', 'doris' ),
				                0   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 1,
                        ),
                        array(
                            'id'=>'section-single-sidebar-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ),
                        
                        array(
                            'id'=>'section-author-start',
                            'title' => esc_html__('Post Author Section Setting', 'doris'),                        
                            'type' => 'section', 
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ), 
                        array(
    						'id'=>'bk-authorbox-sw',
    						'type' => 'switch', 
    						'title' => esc_html__('Enable author box', 'doris'),
    						'subtitle' => esc_html__('Enable author information below single post', 'doris'),
    						'default' => 1,
    						'on' => esc_html__('Enabled', 'doris'),
    						'off' => esc_html__('Disabled', 'doris'),
						),
                        array(
                            'id'=>'section-author-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ), 
                        array(
                            'id'=>'section-postnav-start',
                            'title' => esc_html__('Post Nav Section Setting', 'doris'),                        
                            'type' => 'section', 
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ), 
                        array(
    						'id'=>'bk-postnav-sw',
    						'type' => 'switch', 
    						'title' => esc_html__('Enable post navigation', 'doris'),
    						'subtitle' => esc_html__('Enable post navigation below single post', 'doris'),
    						'default' => 1,
    						'on' => esc_html__('Enabled', 'doris'),
    						'off' => esc_html__('Disabled', 'doris'),
						),                        
                        array(
                            'id'=>'section-postnav-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ), 
                        array(
                            'id'=>'section-related-start',
                            'title' => esc_html__('Related Section Setting', 'doris'),                        
                            'type' => 'section', 
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
    						'id'=>'bk-related-sw',
    						'type' => 'switch',
    						'title' => esc_html__('Enable related posts', 'doris'),
    						'subtitle' => esc_html__('Enable related posts below single post', 'doris'),
    						'default' => 1,
    						'on' => esc_html__('Enabled', 'doris'),
    						'off' => esc_html__('Disabled', 'doris'),
						),
                        array(
                			'id'        => 'bk_related_source',
                            'required' => array('bk-related-sw','=','1'),
                            'title'     => esc_html__('Related Posts', 'doris'),
                            'type'      => 'select', 
                			'options'   => array(
                                            'category_tag' => esc_html__( 'Same Categories and Tags', 'doris' ),
                        					'tag'          => esc_html__( 'Same Tags', 'doris' ),
                                            'category'     => esc_html__( 'Same Categories', 'doris' ),
                                            'author'       => esc_html__( 'Same Author', 'doris' ),
                    				    ),
                			'default'    => 'category_tag',
                		),                        
                        array(
                            'id'=>'section-related-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ),                                                 
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-inbox-box',
    				'title' => esc_html__('Category', 'doris'),
                    'heading'   => esc_html__('Category Pages', 'doris'),
                    'desc'   => esc_html__('Only use for category pages', 'doris'),
    				'fields' => array(
                        array(
    						'id'=>'bk_category_content_layout',
    						'type' => 'image_select', 
    						'title' => esc_html__('Layout', 'doris'),
                            'options'  => array(
                                'listing_list'       => get_template_directory_uri().'/images/admin_panel/archive/1.png',
                                'listing_list_first_large' => get_template_directory_uri().'/images/admin_panel/archive/2.png',
                                'listing_grid'       => get_template_directory_uri().'/images/admin_panel/archive/3.png',
                                'listing_grid_first_large' => get_template_directory_uri().'/images/admin_panel/archive/4.png',
                                'listing_large_post' => get_template_directory_uri().'/images/admin_panel/archive/5.png',
        				    ),
                            'default' => 'listing_list',
						),
                        array(
                            'id'        => 'bk_category_post_icon',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Post Icon', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                'enable'    => esc_html__( 'Enable', 'doris' ),
                                'disable'   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 'enable',
                        ),
                        array(
                            'id'=>'section-category-sidebar-start',
                            'title' => esc_html__('Sidebar', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id'        => 'bk_category_sidebar_select',  
                            'type'      => 'select',
                            'data'      => 'sidebars', 
                            'multi'     => false,
                            'title'     => esc_html__('Category Page Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Choose a sidebar for the category page', 'doris'),
                            'default'   => 'home_sidebar',
                        ),
                        array(
                            'id'        => 'bk_category_sidebar_position',  
                            'type'      => 'image_select',
                            'multi'     => false,
                            'title'     => esc_html__('Sidebar Postion', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                                'right' => array(
                                                    'alt' => 'Sidebar Right',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-right.png',
                                                ),
                                                'left' => array(
                                                    'alt' => 'Sidebar Left',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-left.png',
                                                ),
                                        ),
                            'default' => 'right',
                        ),
                        array(
                            'id'        => 'bk_category_sidebar_sticky',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Stick Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Enable Stick Sidebar / Disable Stick Sidebar', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                1   => esc_html__( 'Enable', 'doris' ),
				                0   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 1,
                        ),
                        array(
                            'id'=>'section-archive-sidebar-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ), 
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-tags',
    				'title' => esc_html__('Archive', 'doris'),
                    'heading'   => esc_html__('Archive Pages', 'doris'),
                    'desc'   => esc_html__('Use for Tag / Archive Pages', 'doris'),
    				'fields' => array(
                        array(
    						'id'=>'bk_archive_header_style',
    						'type' => 'select', 
    						'title' => esc_html__('Page Heading', 'doris'),
                            'options'  => array(
                                'grey-bg'           => esc_html__( 'Grey Background', 'doris' ),
                                'grey-bg-center'    => esc_html__( 'Grey Background -- Align Center', 'doris' ),
            					'image-bg'          => esc_html__( 'Featured Image Background', 'doris' ),
                                'image-bg-center'   => esc_html__( 'Featured Image Background -- Align Center', 'doris' ),
                            ),
                            'default' => 'grey-bg',
						),
                        array(
    						'id'=>'bk_archive_content_layout',
    						'type' => 'image_select', 
    						'title' => esc_html__('Content Layout', 'doris'),
                            'options'  => array(
                                'listing_list'       => get_template_directory_uri().'/images/admin_panel/archive/1.png',
                                'listing_list_first_large' => get_template_directory_uri().'/images/admin_panel/archive/2.png',
                                'listing_grid'       => get_template_directory_uri().'/images/admin_panel/archive/3.png',
                                'listing_grid_first_large' => get_template_directory_uri().'/images/admin_panel/archive/4.png',
                                'listing_large_post' => get_template_directory_uri().'/images/admin_panel/archive/5.png',
        				    ),
                            'default' => 'listing_list',
						),
                        array(
                            'id'        => 'bk_archive_post_icon',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Post Icon', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                'enable'    => esc_html__( 'Enable', 'doris' ),
                                'disable'   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 'enable',
                        ),
                        array(
                            'id'=>'section-archive-sidebar-start',
                            'title' => esc_html__('Sidebar', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id'        => 'bk_archive_sidebar_select',  
                            'type'      => 'select',
                            'data'      => 'sidebars', 
                            'multi'     => false,
                            'title'     => esc_html__('Archive Page Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Choose a sidebar for the archive page', 'doris'),
                            'default'   => 'home_sidebar',
                        ),
                        array(
                            'id'        => 'bk_archive_sidebar_position',  
                            'type'      => 'image_select',
                            'multi'     => false,
                            'title'     => esc_html__('Sidebar Postion', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                                'right' => array(
                                                    'alt' => 'Sidebar Right',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-right.png',
                                                ),
                                                'left' => array(
                                                    'alt' => 'Sidebar Left',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-left.png',
                                                ),
                                        ),
                            'default' => 'right',
                        ),
                        array(
                            'id'        => 'bk_archive_sidebar_sticky',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Stick Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Enable Stick Sidebar / Disable Stick Sidebar', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                1   => esc_html__( 'Enable', 'doris' ),
				                0   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 1,
                        ),
                        array(
                            'id'=>'section-archive-sidebar-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ), 
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-group',
    				'title' => esc_html__('Author Page', 'doris'),
    				'fields' => array(
                        array(
    						'id'=>'bk_author_content_layout',
    						'type' => 'image_select', 
    						'title' => esc_html__('Content Layout', 'doris'),
                            'options'  => array(
                                'listing_list'       => get_template_directory_uri().'/images/admin_panel/archive/1.png',
                                'listing_list_first_large' => get_template_directory_uri().'/images/admin_panel/archive/2.png',
                                'listing_grid'       => get_template_directory_uri().'/images/admin_panel/archive/3.png',
                                'listing_grid_first_large' => get_template_directory_uri().'/images/admin_panel/archive/4.png',
                                'listing_large_post' => get_template_directory_uri().'/images/admin_panel/archive/5.png',
        				    ),
                            'default' => 'listing_list',
						),
                        array(
                            'id'        => 'bk_author_post_icon',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Post Icon', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                'enable'    => esc_html__( 'Enable', 'doris' ),
                                'disable'   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 'enable',
                        ),
                        array(
                            'id'=>'section-author-sidebar-start',
                            'title' => esc_html__('Sidebar', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id'        => 'bk_author_sidebar_select',  
                            'type'      => 'select',
                            'data'      => 'sidebars', 
                            'multi'     => false,
                            'title'     => esc_html__('Author Page Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Choose a sidebar for the author page', 'doris'),
                            'default'   => 'home_sidebar',
                        ),
                        array(
                            'id'        => 'bk_author_sidebar_position',  
                            'type'      => 'image_select',
                            'multi'     => false,
                            'title'     => esc_html__('Sidebar Postion', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                                'right' => array(
                                                    'alt' => 'Sidebar Right',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-right.png',
                                                ),
                                                'left' => array(
                                                    'alt' => 'Sidebar Left',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-left.png',
                                                ),
                                        ),
                            'default' => 'right',
                        ),
                        array(
                            'id'        => 'bk_author_sidebar_sticky',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Stick Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Enable Stick Sidebar / Disable Stick Sidebar', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                1   => esc_html__( 'Enable', 'doris' ),
				                0   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 1,
                        ),
                        array(
                            'id'=>'section-author-sidebar-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ), 
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-search',
    				'title' => esc_html__('Search Page', 'doris'),
    				'fields' => array(
                        array(
    						'id'=>'bk_search_content_layout',
    						'type' => 'image_select', 
    						'title' => esc_html__('Content Layout', 'doris'),
                            'options'  => array(
                                'listing_list'       => get_template_directory_uri().'/images/admin_panel/archive/1.png',
                                'listing_list_first_large' => get_template_directory_uri().'/images/admin_panel/archive/2.png',
                                'listing_grid'       => get_template_directory_uri().'/images/admin_panel/archive/3.png',
                                'listing_grid_first_large' => get_template_directory_uri().'/images/admin_panel/archive/4.png',
                                'listing_large_post' => get_template_directory_uri().'/images/admin_panel/archive/5.png',
        				    ),
                            'default' => 'listing_list',
						),
                        array(
                            'id'        => 'bk_search_post_icon',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Post Icon', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                'enable'    => esc_html__( 'Enable', 'doris' ),
                                'disable'   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 'enable',
                        ),
                                   
                        array(
                            'id'=>'section-search-sidebar-start',
                            'title' => esc_html__('Sidebar', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id'        => 'bk_search_sidebar_select',  
                            'type'      => 'select',
                            'data'      => 'sidebars', 
                            'multi'     => false,
                            'title'     => esc_html__('Search Page Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Choose a sidebar for the search page', 'doris'),
                            'default'   => 'home_sidebar',
                        ),
                        array(
                            'id'        => 'bk_search_sidebar_position',  
                            'type'      => 'image_select',
                            'multi'     => false,
                            'title'     => esc_html__('Sidebar Postion', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                                'right' => array(
                                                    'alt' => 'Sidebar Right',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-right.png',
                                                ),
                                                'left' => array(
                                                    'alt' => 'Sidebar Left',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-left.png',
                                                ),
                                        ),
                            'default' => 'right',
                        ),
                        array(
                            'id'        => 'bk_search_sidebar_sticky',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Stick Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Enable Stick Sidebar / Disable Stick Sidebar', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                1   => esc_html__( 'Enable', 'doris' ),
				                0   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 1,
                        ),
                        array(
                            'id'=>'section-search-sidebar-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ), 
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-pencil',
    				'title' => esc_html__('Blog Page', 'doris'),
    				'fields' => array(
                        array(
    						'id'=>'bk_blog_content_layout',
    						'type' => 'image_select', 
    						'title' => esc_html__('Content Layout', 'doris'),
                            'options'  => array(
                                'listing_list'       => get_template_directory_uri().'/images/admin_panel/archive/1.png',
                                'listing_list_first_large' => get_template_directory_uri().'/images/admin_panel/archive/2.png',
                                'listing_grid'       => get_template_directory_uri().'/images/admin_panel/archive/3.png',
                                'listing_grid_first_large' => get_template_directory_uri().'/images/admin_panel/archive/4.png',
                                'listing_large_post' => get_template_directory_uri().'/images/admin_panel/archive/5.png',
        				    ),
                            'default' => 'listing_list',
						),
                        array(
                            'id'        => 'bk_blog_post_icon',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Post Icon', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                'enable'    => esc_html__( 'Enable', 'doris' ),
                                'disable'   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 'enable',
                        ),
                        array(
                            'id'=>'section-blog-sidebar-start',
                            'title' => esc_html__('Sidebar', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id'        => 'bk_blog_sidebar_select',  
                            'type'      => 'select',
                            'data'      => 'sidebars', 
                            'multi'     => false,
                            'title'     => esc_html__('Blog Page Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Choose a sidebar for the blog page', 'doris'),
                            'default'   => 'home_sidebar',
                        ),
                        array(
                            'id'        => 'bk_blog_sidebar_position',  
                            'type'      => 'image_select',
                            'multi'     => false,
                            'title'     => esc_html__('Sidebar Postion', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                                'right' => array(
                                                    'alt' => 'Sidebar Right',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-right.png',
                                                ),
                                                'left' => array(
                                                    'alt' => 'Sidebar Left',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-left.png',
                                                ),
                                        ),
                            'default' => 'right',
                        ),
                        array(
                            'id'        => 'bk_blog_sidebar_sticky',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Stick Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Enable Stick Sidebar / Disable Stick Sidebar', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                1   => esc_html__( 'Enable', 'doris' ),
				                0   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 1,
                        ),
                        array(
                            'id'=>'section-blog-sidebar-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ), 
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-error-alt',
    				'title' => esc_html__('404 Page', 'doris'),
    				'fields' => array(
                        array(
                            'id'=>'section-404-text-start',
                            'title' => esc_html__('404 Text', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id'       => '404--sub-title-text',
                            'type'     => 'textarea',
                            'rows'     => 3,
                            'title'    => esc_html__('Sub Title Text', 'doris'),
                            'default'  => ''
                        ),   
                        array(
                            'id'       => '404--notice-text',
                            'type'     => 'textarea',
                            'rows'     => 3,
                            'title'    => esc_html__('Notice Text', 'doris'),
                            'default'  => ''
                        ),
                        array(
                            'id'=>'section-404-text-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id'        => '404-search',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Search Field', 'doris'),
                            'subtitle'  => esc_html__('Enable / Disable Search Field', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                1   => esc_html__( 'Enable', 'doris' ),
				                0   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 1,
                        ),                        
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-minus',
    				'title' => esc_html__('Default Page Template', 'doris'),
                    'heading'   => esc_html__('Default Page Template', 'doris'),
                    'desc'   => esc_html__('Default Page Template Configuration', 'doris'),
    				'fields' => array(
                        array(
                            'id'        => 'bk_page_feat_img',
                            'title'     => esc_html__( 'Feature Image Show/Hide', 'doris' ),
                            'type'      => 'switch', 
                			'options'   => array(          
                                            1 => esc_html__( 'Show', 'doris' ),
                                            0 => esc_html__( 'Hide', 'doris' ),
                    				    ),
                			'default'    => 1,
                        ),
                        array(
    						'id'=>'bk_page_layout',
    						'type' => 'select', 
    						'title' => esc_html__('Layout', 'doris'),
                            'options'  => array(
                                'has_sidebar' => esc_html__( 'Has Sidebar', 'doris' ),
                                'no_sidebar'  => esc_html__( 'Full Width -- No sidebar', 'doris' ),
        				    ),
                            'default' => 'has_sidebar',
						),
                        array(
                            'id'=>'section-default-page--sidebar-start',
                            'title' => esc_html__('Sidebar', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id'        => 'bk_page_sidebar_select',  
                            'type'      => 'select',
                            'data'      => 'sidebars', 
                            'multi'     => false,
                            'title'     => esc_html__('Page Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Choose a sidebar for the page', 'doris'),
                            'default'   => 'home_sidebar',
                        ),
                        array(
                            'id'        => 'bk_page_sidebar_position',  
                            'type'      => 'image_select',
                            'multi'     => false,
                            'title'     => esc_html__('Sidebar Postion', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                                'right' => array(
                                                    'alt' => 'Sidebar Right',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-right.png',
                                                ),
                                                'left' => array(
                                                    'alt' => 'Sidebar Left',
                                                    'img' => get_template_directory_uri().'/images/admin_panel/archive/sb-left.png',
                                                ),
                                        ),
                            'default' => 'right',
                        ),
                        array(
                            'id'        => 'bk_page_sidebar_sticky',  
                            'type'      => 'button_set',
                            'multi'     => false,
                            'title'     => esc_html__('Stick Sidebar', 'doris'),
                            'subtitle'  => esc_html__('Enable Stick Sidebar / Disable Stick Sidebar', 'doris'),
                            'desc'      => '',
                            'options'   => array(
                                1   => esc_html__( 'Enable', 'doris' ),
				                0   => esc_html__( 'Disable', 'doris' ),
                            ),
                            'default' => 1,
                        ),
                        array(
                            'id'=>'section-default-page--sidebar-end',
                            'type' => 'section', 
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ), 
    				)
    			);
                $this->sections[] = array(
    				'icon' => 'el-icon-website',
    				'title' => esc_html__('Footer', 'doris'),
    				'fields' => array(
                        array(
    						'id'=>'bk-footer-logo',
    						'type' => 'media', 
    						'url'=> true,
    						'title' => esc_html__('Footer Logo', 'doris'),
    						'subtitle' => esc_html__('Upload logo of your site that is displayed in footer bar', 'doris'),
                            'placeholder' => esc_html__('No media selected','doris')
						),
                        
                        array(
                            'id' => 'section-social-footer-start',
                            'title' => esc_html__('Footer Social Items', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),	
                        array(
    						'id'       =>'bk-social-footer',
    						'type'     => 'select',
                            'multi'    => true,
    						'title' => esc_html__('Social Media', 'doris'),
    						'subtitle' => esc_html__('Select social items for the website', 'doris'),
    						'options'  => array('fb'=>'Facebook', 'twitter'=>'Twitter', 'linkedin'=>'Linkedin',
                                               'pinterest'=>'Pinterest', 'instagram'=>'Instagram', 'dribbble'=>'Dribbble', 
                                               'youtube'=>'Youtube', 'vimeo'=>'Vimeo', 'vk'=>'VK', 'vine'=>'Vine',
                                               'snapchat'=>'SnapChat', 'rss'=>'RSS'),
    						'default' => array('fb'=>'', 'twitter'=>'', 'linkedin'=>'', 'pinterest'=>'', 'instagram'=>'', 'dribbble'=>'', 
                                                'youtube'=>'', 'vimeo'=>'', 'vk'=>'', 'vine'=>'', 'snapchat'=>'', 'rss'=>'')
						),
                        array(
                            'id' => 'section-social-footer-end',
                            'type' => 'section',                             
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ),
                        
                        array(
                            'id' => 'section-copyright-footer-start',
                            'title' => esc_html__('Footer Copyright', 'doris'),
                            'type' => 'section',                             
                            'indent' => true // Indent all options below until the next 'section' option is set.
                        ),
                        array(
                            'id'       => 'bk-footer-copyright',
                            'type'     => 'textarea', 
                            'title'    => esc_html__('Footer Copyright Text', 'doris'),
                            'default'  => '',
                        ),
                        array(
                            'id' => 'section-copyright-footer-end',
                            'type' => 'section',                             
                            'indent' => false // Indent all options below until the next 'section' option is set.
                        ),
    				)
    			);
			$theme_info = '<div class="redux-framework-section-desc">';
			$theme_info .= '<p class="redux-framework-theme-data description theme-uri">'.__('<strong>Theme URL:</strong> ', 'doris').'<a href="'.$this->theme->get('ThemeURI').'" target="_blank">'.$this->theme->get('ThemeURI').'</a></p>';
			$theme_info .= '<p class="redux-framework-theme-data description theme-author">'.__('<strong>Author:</strong> ', 'doris').$this->theme->get('Author').'</p>';
			$theme_info .= '<p class="redux-framework-theme-data description theme-version">'.__('<strong>Version:</strong> ', 'doris').$this->theme->get('Version').'</p>';
			$theme_info .= '<p class="redux-framework-theme-data description theme-description">'.$this->theme->get('Description').'</p>';
			$tabs = $this->theme->get('Tags');
			if ( !empty( $tabs ) ) {
				$theme_info .= '<p class="redux-framework-theme-data description theme-tags">'.__('<strong>Tags:</strong> ', 'doris').implode(', ', $tabs ).'</p>';	
			}
			$theme_info .= '</div>';

			$this->sections[] = array(
				'type' => 'divide',
			);

		}	

		public function setHelpTabs() {

		}


		/**
			
			All the possible arguments for Redux.
			For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments

		 **/
		public function setArguments() {
			
			$theme = wp_get_theme(); // For use with some settings. Not necessary.

			$this->args = array(
	            
	            // TYPICAL -> Change these values as you need/desire
				'opt_name'          	=> 'doris_option', // This is where your data is stored in the database and also becomes your global variable name.
				'display_name'			=> $theme->get('Name'), // Name that appears at the top of your panel
				'display_version'		=> $theme->get('Version'), // Version that appears at the top of your panel
				'menu_type'          	=> 'menu', //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
				'allow_sub_menu'     	=> true, // Show the sections below the admin menu item or not
				'menu_title'			=> esc_html__( 'Theme Options', 'doris' ),
	            'page'		 	 		=> esc_html__( 'Theme Options', 'doris' ),
	            'google_api_key'   	 	=> 'AIzaSyBdxbxgVuwQcnN5xCZhFDSpouweO-yJtxw', // Must be defined to add google fonts to the typography module
	            'global_variable'    	=> '', // Set a different name for your global variable other than the opt_name
	            'dev_mode'           	=> false, // Show the time the page took to load, etc
	            'customizer'         	=> true, // Enable basic customizer support
                'google_update_weekly'  => true, //This will only function if you have a google_api_key provided. This argument tells the core to grab the Google fonts cache weekly, ensuring your font list is always up to date.

	            // OPTIONAL -> Give you extra features
	            'page_priority'      	=> null, // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
	            'page_parent'        	=> 'themes.php', // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
	            'page_permissions'   	=> 'manage_options', // Permissions needed to access the options panel.
	            'menu_icon'          	=> '', // Specify a custom URL to an icon
	            'last_tab'           	=> '', // Force your panel to always open to a specific tab (by id)
	            'page_icon'          	=> 'icon-themes', // Icon displayed in the admin panel next to your menu_title
	            'page_slug'          	=> '_options', // Page slug used to denote the panel
	            'save_defaults'      	=> true, // On load save the defaults to DB before user clicks save or not
	            'default_show'       	=> false, // If true, shows the default value next to each field that is not the default value.
	            'default_mark'       	=> '', // What to print by the field's title if the value shown is default. Suggested: *


	            // CAREFUL -> These options are for advanced use only
	            'transient_time' 	 	=> 60 * MINUTE_IN_SECONDS,
	            'output'            	=> true, // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
	            'output_tag'            	=> true, // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
	            //'domain'             	=> 'redux-framework', // Translation domain key. Don't change this unless you want to retranslate all of Redux.
	            //'footer_credit'      	=> '', // Disable the footer credit of Redux. Please leave if you can help it.
	            

	            // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
	            'database'           	=> '', // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
	            
	        
	            'show_import_export' 	=> true, // REMOVE
	            'system_info'        	=> false, // REMOVE
	            
	            'help_tabs'          	=> array(),
	            'help_sidebar'       	=> '', // esc_html__( '', $this->args['domain'] );            
				);


			// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.		
			$this->args['share_icons'][] = array(
			    'url' => 'https://github.com/ReduxFramework/ReduxFramework',
			    'title' => 'Visit us on GitHub', 
			    'icon' => 'el-icon-github'
			    // 'img' => '', // You can use icon OR img. IMG needs to be a full URL.
			);		
			$this->args['share_icons'][] = array(
			    'url' => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
			    'title' => 'Like us on Facebook', 
			    'icon' => 'el-icon-facebook'
			);
			$this->args['share_icons'][] = array(
			    'url' => 'http://twitter.com/reduxframework',
			    'title' => 'Follow us on Twitter', 
			    'icon' => 'el-icon-twitter'
			);
			$this->args['share_icons'][] = array(
			    'url' => 'http://www.linkedin.com/company/redux-framework',
			    'title' => 'Find us on LinkedIn', 
			    'icon' => 'el-icon-linkedin'
			);

			
	 
			// Panel Intro text -> before the form
			if (!isset($this->args['global_variable']) || $this->args['global_variable'] !== false ) {
				if (!empty($this->args['global_variable'])) {
					$v = $this->args['global_variable'];
				} else {
					$v = str_replace("-", "_", $this->args['opt_name']);
				}
				$this->args['intro_text'] = '';
			} else {
				$this->args['intro_text'] = '';
			}

			// Add content after the form.
			$this->args['footer_text'] = '' ;

		}
	}
	new Redux_Framework_config();

}


/** 

	Custom function for the callback referenced above

 */
if ( !function_exists( 'redux_my_custom_field' ) ):
	function redux_my_custom_field($field, $value) {
	    print_r($field);
	    print_r($value);
	}
endif;

/**
 
	Custom function for the callback validation referenced above

**/
if ( !function_exists( 'redux_validate_callback_function' ) ):
	function redux_validate_callback_function($field, $value, $existing_value) {
	    $error = false;
	    $value =  'just testing';
	    
	    $return['value'] = $value;
	    if($error == true) {
	        $return['error'] = $field;
	    }
	    return $return;
	}
endif;
